#!/bin/bash

function wait_for_secrets_manager() {
  echo "Waiting for Secrets Manager to start..."
  wait_for_service "aws --region=us-east-1 --endpoint-url=${SECRETS_MANAGER_ENDPOINT} secretsmanager list-secrets"
}

function wait_for_sqs() {
  echo "Waiting for Sqs to start..."
  wait_for_service "aws --region=us-east-1 --endpoint-url=${SQS_ENDPOINT} sqs list-queues"
}

function wait_for_lambda() {
  echo "Waiting for lambda to start..."
  wait_for_service "aws --region=us-east-1 --endpoint-url=${LAMBDA_ENDPOINT} lambda list-functions"
}

function wait_for_s3() {
  echo "Waiting for s3 to start..."
  wait_for_service "aws --region=us-east-1 --endpoint-url=${S3_ENDPOINT} s3 ls"
}

function wait_for_service() {
  n=0
  until [ $n -ge ${2-10} ]
  do
    eval "$1" && break
    n=$((n+1))
    echo "retrying attempt ${n}"
    sleep $((n+5))
  done
}

function fail {
  echo $1 >&2
  exit 1
}

function retry {
  local n=1
  local max=10
  local delay=10
  while true; do
    eval "$@" && break || {
      if [[ $n -lt $max ]]; then
        ((n++))
        echo "Attempting to bring up service, Attempt $n/$max:"
        sleep $delay;
      else
        docker ps
        fail "Failed to bring up service after $n attempts."
      fi
    }
  done
}